#include "karambasaverui.h"

/*
 *  Constructs a karambasaverUI as a child of 'parent', with the
 *  name 'name' and widget flags set to 'f'.
 *
 *  The dialog will by default be modeless, unless you set 'modal' to
 *  TRUE to construct a modal dialog.
 */
karambasaverUI::karambasaverUI( QWidget* parent, const char* name, bool modal, WFlags fl )
    : QDialog( parent, name, modal, fl ){
    if ( !name )
	setName( "karambasavercfg" );

    QWidget* privateLayoutWidget = new QWidget( this, "Layout2" );
    readSettings();
    privateLayoutWidget->setGeometry( QRect( 5, 0, 265, 87 ) );
    Layout2 = new QGridLayout( privateLayoutWidget, 1, 1, KDialog::marginHint(), KDialog::spacingHint(), "Layout2");

    themeLabel = new QLabel( privateLayoutWidget, "themeLabel" );
    Layout2->addWidget( themeLabel, 0, 0 );

    dTheme = new QLineEdit( privateLayoutWidget, "dTheme" );
    dTheme->setText(theme);
    Layout2->addWidget( dTheme, 1, 0 );

    browse = new QPushButton( privateLayoutWidget, "browse" );
    Layout2->addWidget( browse, 1, 1 );

    Layout1 = new QHBoxLayout( 0, 0, KDialog::spacingHint(), "Layout1"); 

    OkayPushButton = new QPushButton( privateLayoutWidget, "OkayPushButton" );
    Layout1->addWidget( OkayPushButton );

    CancelPushButton = new QPushButton( privateLayoutWidget, "CancelPushButton" );
    Layout1->addWidget( CancelPushButton );

    Layout2->addLayout( Layout1, 2, 0 );
    languageChange();
    resize( QSize(267, 90).expandedTo(minimumSizeHint()) );
    connect( browse, SIGNAL( clicked() ), this, SLOT( selDefaultTheme() ) );
}

/*
 *  Destroys the object and frees any allocated resources
 */
karambasaverUI::~karambasaverUI()
{
    // no need to delete child widgets, Qt does it all for us
}

/*
 *  Sets the strings of the subwidgets using the current
 *  language.
 */
void karambasaverUI::languageChange()
{
    setCaption( tr2i18n( "Screen Saver Config" ) );
    OkayPushButton->setText( tr2i18n( "&OK" ) );
    CancelPushButton->setText( tr2i18n( "&Cancel" ) );
    browse->setText( tr2i18n( "Browse" ) );
    themeLabel->setText( tr2i18n( "Choose your theme." ) );
}

void karambasaverUI::readSettings(){
  KSimpleConfig conf("karambasaverrc",true);
  conf.setGroup("Settings");
  theme =  conf.readEntry("DefaultTheme", "");
}

void karambasaverUI::selDefaultTheme(){
    QString fileName;
    fileName = KFileDialog::getOpenFileName(Dir, "*.theme", 0, "Open configurations");
    QUrl url(fileName); //make QUrl from QString
    fileName = (url.dirPath() == Dir)?url.fileName():fileName; //verify if the theme is in default dir
    if( fileName != ""){
      dTheme->setText( fileName );
      theme = fileName;
    }
}

#include "karambasaverui.moc"
